==> cosmo_1.0.tar.gz: cosmo/src/INCLUDE/constraints.h <==
int deriveAllModels(
		     DATASET *dataSet   /* the dataset */
		     );

BOOLEAN deriveModel(
		    DATASET *dataSet,  /* the dataset */
		    int width,         /* motif width */
		    int modTypeNum,    /* model type number */
		    int conSetNum      /* constraint set number */
		    );

int readConFile(
		DATASET *dataSet       /* the dataset */
		);

int checkConSetNum(
		    int conSetNum,         /* the constraint set number to check*/
		    int numConSets         /* the number of constraint sets */
		    );

int checkInput(
		CONSET *conSets,      /* array of constraint sets */
		int intNum,           /* the interval number to check */
		int cSetNum,          /* the constraint set number to check */
		int numConSets        /* the number of constraint sets */
		);

int addPalCon(
	       CONSET *cSet,            /* array of constraint sets */
	       FILE *conFile,           /* the constraint file */
	       int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
	       char *line,              /* character arrays for line-by-line input */
	       char *word,
	       char *first
	       );

int addSubCon(
	       CONSET *cSet,            /* array of constraint sets */
	       FILE *conFile,           /* the constraint file */
	       int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
	       char *line,              /* character arrays for line-by-line input */
	       char *word,
	       char *first
	       );

int addLinCon(
	       CONSET *cSet,            /* array of constraint sets */
	       FILE *conFile,           /* the constraint file */
	       int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
	       char *line,              /* character arrays for line-by-line input */
	       char *word,
	       char *first
	       );

int addPosFreqCon(
		   CONSET *cSet,            /* array of constraint sets */
		   FILE *conFile,           /* the constraint file */
		   int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		   int intNum,              /* the interval to which the shape constraint is added */
		   int pos,
		   char *line,              /* character arrays for line-by-line input */
		   char *word,
		   char *first
		   );

int addIntFreqCon(
		   CONSET *cSet,            /* array of constraint sets */
		   FILE *conFile,           /* the constraint file */
		   int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		   int intNum,              /* the interval to which the shape constraint is added */
		   char *line,              /* character arrays for line-by-line input */
		   char *word,
		   char *first
		   );

int addBoundCon(
		 CONSET *cSet,            /* array of constraint sets */
		 FILE *conFile,           /* the constraint file */
		 int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		 int intNum,              /* the interval to which the shape constraint is added */
		 char *line,              /* character arrays for line-by-line input */
		 char *word,
		 char *first
		 );

int addShapeCon(
		 CONSET *cSet,            /* array of constraint sets */
		 FILE *conFile,           /* the constraint file */
		 int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		 int intNum,              /* the interval to which the shape constraint is added */
		 char *line,              /* character arrays for line-by-line input */
		 char *word,
		 char *first
		 );

int initConSets(
		DATASET *dataSet
		);

int addConstraints(
		   DATASET *dataSet
		   );

int findLine(
	      FILE *conFile,           /* the constraint file */
	      char *line,              /* character array for line-by-line input */
	      char *first,             /* character array for line-by-line input */
	      char *param,             /* the parameter to find */
	      char *command,           /* the command for which to find the parameter */             
	      char before,             /* character that must not be found before parameter */
	      int chop                 /* should the last character be chopped off? */
	      );

int findCommand(
		FILE *conFile,           /* the constraint file */
		char *line,              /* character array for line-by-line input */
		char symbol,             /* the symbol at the beginning of the line to look for */
		char before              /* the character that must not be found before the symbol */
		);


int getMaxNumProfParms(
			DATASET *dataSet
			);

int getMaxNumInts(
		   DATASET *dataSet
		   );

int getHiProb(
	       DATASET *dataSet
	       );

int getNumConSets(
		  DATASET *dataSet
		  );

int getNumInts(
	       DATASET *dataSet,
	       int *numInts
	       );

==> cosmo_1.6.0.tar.gz: cosmo/src/INCLUDE/constraints.h <==
int deriveAllModels(
		     DATASET *dataSet   /* the dataset */
		     );

BOOLEAN deriveModel(
		    DATASET *dataSet,  /* the dataset */
		    int width,         /* motif width */
		    int modTypeNum,    /* model type number */
		    int conSetNum      /* constraint set number */
		    );

int readConFile(
		DATASET *dataSet       /* the dataset */
		);

int checkConSetNum(
		    int conSetNum,         /* the constraint set number to check*/
		    int numConSets         /* the number of constraint sets */
		    );

int checkInput(
		CONSET *conSets,      /* array of constraint sets */
		int intNum,           /* the interval number to check */
		int cSetNum,          /* the constraint set number to check */
		int numConSets        /* the number of constraint sets */
		);

int addPalCon(
	       CONSET *cSet,            /* array of constraint sets */
	       CONSTRING *conString,    /* the constraint file */
	       int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
	       char *line,              /* character arrays for line-by-line input */
	       char *word,
	       char *first
	       );

int addSubCon(
	       CONSET *cSet,            /* array of constraint sets */
	       CONSTRING *conString,    /* the constraint file */
	       int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
	       char *line,              /* character arrays for line-by-line input */
	       char *word,
	       char *first
	       );

int addLinCon(
	       CONSET *cSet,            /* array of constraint sets */
	       CONSTRING *conString,    /* the constraint file */
	       int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
	       char *line,              /* character arrays for line-by-line input */
	       char *word,
	       char *first
	       );

int addPosFreqCon(
		   CONSET *cSet,            /* array of constraint sets */
		   CONSTRING *conString,           /* the constraint file */
		   int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		   int intNum,              /* the interval to which the shape constraint is added */
		   int pos,
		   char *line,              /* character arrays for line-by-line input */
		   char *word,
		   char *first
		   );

int addIntFreqCon(
		   CONSET *cSet,            /* array of constraint sets */
		   CONSTRING *conString,    /* the constraint file */
		   int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		   int intNum,              /* the interval to which the shape constraint is added */
		   char *line,              /* character arrays for line-by-line input */
		   char *word,
		   char *first
		   );

int addBoundCon(
		 CONSET *cSet,            /* array of constraint sets */
		 CONSTRING *conString,    /* the constraint file */
		 int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		 int intNum,              /* the interval to which the shape constraint is added */
		 char *line,              /* character arrays for line-by-line input */
		 char *word,
		 char *first
		 );

int addShapeCon(
		 CONSET *cSet,            /* array of constraint sets */
		 CONSTRING *conString,    /* constraint file in CONSTRING */
		 int cSetNum,             /* the index of the constraint set to which the shape constraint is added */
		 int intNum,              /* the interval to which the shape constraint is added */
		 char *line,              /* character arrays for line-by-line input */
		 char *word,
		 char *first
		 );

int initConSets(
		DATASET *dataSet
		);

int addConstraints(
		   DATASET *dataSet
		   );

int findLine(
	     CONSTRING *conString,    /* the constraint file CONSTRING */
	     char *line,              /* character array for line-by-line input */
	     char *first,             /* character array for line-by-line input */
	     char *param,             /* the parameter to find */
	     char *command,           /* the command for which to find the parameter */             
	     char before,             /* character that must not be found before parameter */
	     int chop                 /* should the last character be chopped off? */
	     );

int findCommand(
		CONSTRING *conString,    /* the constraint file */
		char *line,              /* character array for line-by-line input */
		char symbol,             /* the symbol at the beginning of the line to look for */
		char before              /* the character that must not be found before the symbol */
		);


int getMaxNumProfParms(
			DATASET *dataSet
			);

int getMaxNumInts(
		   DATASET *dataSet
		   );

int getHiProb(
	       DATASET *dataSet
	       );

int getNumConSets(
		  DATASET *dataSet
		  );

int getNumInts(
	       DATASET *dataSet,
	       int *numInts
	       );

int conFile2conString(
		      DATASET *dataSet
		      );

char* getLine(
	      CONSTRING *conString,
	      char *line
	      );

int rewindConString(
		    CONSTRING *conString
		    );


int string2conString(
		     DATASET *dataSet,
		     char *constraints
		     );

double getIntensity(
		    MTYPE mType,          /* model type */
 		    int width,            /* width of motif */
		    int numSites,         /* expected number of motif occurrences */
		    DATASET *dataSet      /* the dataset */
		    );
